<?php
/*
Plugin Name: Class Makr
Plugin URI: https://classmakr.com/
Description: Setup your own online classes now. Use '[MASTER_CLASS]' shortcode, a grid of all class category.
Version: 1.2.1
Author: ClassMakr
Author URI: https://classmakr.com/
*/

register_activation_hook(__FILE__, 'MasterClassValidateSetup');
function MasterClassValidateSetup() {
    if (is_plugin_active('class-makr-pro/class-makr-pro.php') )
    {
        deactivate_plugins('class-makr-pro/class-makr-pro.php');
    }
}

add_action('admin_init','show_me');
function show_me(){
  if(!is_ssl()){
    add_action('admin_notices','mc_show_ssl_not_found_msg');
  }
}

include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
require( ABSPATH . WPINC . '/pluggable.php' );
require( ABSPATH . WPINC . '/pluggable-deprecated.php' );


register_activation_hook( __FILE__, 'add_master_class_data' );
define( 'MC_BASE', plugin_basename( __FILE__ ) );
define( 'MC_DIR', plugin_dir_path( __FILE__ ) );
define( 'MC_URL', plugin_dir_url( __FILE__ ) );
define( 'MC_AST', MC_URL.'assets' );
define( 'MC_IMG', MC_URL.'assets/images' );
define( 'MC_CSS', MC_AST.'/CSS' );
define( 'MC_JS', MC_AST.'/js' );
define( 'MC_REQ_CLS', MC_DIR.'requires/classes' );
define( 'MC_REQ_VWS', MC_DIR.'requires/views' );

if (!is_plugin_active('class-makr-pro/class-makr-pro.php') )
{
  
  require MC_REQ_CLS.'/class-makr-full-width-template-class.php';
  add_action( 'plugins_loaded', array( 'ClassMakrFullWidthTemplate', 'get_instance' ) );
  
  require MC_DIR.'requires/support/elementor/app-wdget.php';

  require MC_DIR.'requires/support/drag-drop/simple-custom-post-order.php';
  require MC_DIR.'requires/support/email/tesseract-email-customizer-admin.php';

  require MC_DIR.'requires/support/payments/stripe/Stripe.php' ;
  require MC_DIR.'requires/support/payments/authorize/autoload.php';
  require_once MC_DIR . 'requires/support/payments/square-sdk/autoload.php';

  require MC_REQ_CLS.'/css-js-controller.php';
  new Master_CSS_JS_Controller;

  require MC_REQ_CLS.'/email-template.php';
  new MC_Email_Template_Controller;

  require MC_REQ_CLS.'/common-functions-controller.php';
  new Common_Functions_Controller;

  require MC_REQ_CLS.'/navigation-controller.php';
  new Navigation_Controller;

  require MC_REQ_CLS.'/register-controller.php';
  new Master_Register_Controller;

  require MC_REQ_CLS.'/metabox-controller.php';
  new Master_Metabox_Controller;

  require MC_REQ_CLS.'/shortcode-controller.php';
  new Master_Shortcode_Controller;

  require MC_REQ_CLS.'/template-redirect-controller.php';
  new Template_Redirect_Controller;

  require MC_REQ_CLS.'/lesson-functions.php';
  new Master_Lesson_Functions;

  require MC_REQ_CLS.'/lesson-before-content.php';
  new Master_Lesson_Before_Content;

  require MC_REQ_CLS.'/lesson-after-content.php';
  new Master_Lesson_After_Content;

  require MC_REQ_CLS.'/coupon-controller.php';
  new MC_Coupon_Controller;

  require MC_REQ_CLS.'/payment-controller.php';
  new MC_Payment_Controller;

  require MC_REQ_CLS.'/email-api-controller.php';
  new Master_Email_API_Controller;

  require MC_REQ_CLS.'/login-register-controller.php';
  new MC_Login_Register_Controller;

  require MC_REQ_CLS.'/square-payment-controller.php';
  new MC_Square_Payment_Controller;

  require MC_REQ_CLS.'/user-details-controller.php';
  new MC_User_Details_Controller;

  require MC_REQ_CLS.'/general-settings-controller.php';
  new Master_General_Settings_Controller;

  require MC_REQ_CLS.'/bundle-controller.php';
  new MC_Bundle_Controller;

  require MC_REQ_CLS.'/my-account-controller.php';
  new MC_My_Account_Controller;

  require MC_REQ_CLS.'/guide-book.php';
  new Master_GuideBook_Controller;
  
}


add_filter( 'body_class', function( $classes ) {
	return array_merge( $classes, array( 'mc-class-active') );
} );

if(isset($_POST)){
	if( isset($_POST['_mc_grad_is_submit']) && $_POST['_mc_grad_is_submit']  == 'yes' ){
		Master_Lesson_Functions::save_gradation($_POST);
	}else{
		return;
	}
}
function add_master_class_data(){
	add_role( 'mc_learner', 'Learner', array( 'read' => true, 'edit_posts' => false ) );

    $mc_login =  get_page_by_title( 'MC Login' );
    if($mc_login == NULL || $mc_login->post_status == 'trash'){
      $login_page = array(
        'post_title'    => 'MC Login',
        'post_content'  => '[MASTERCLASS_LOGIN]',
        'post_status'   => 'publish',
        'post_author'   => get_current_user_id(),
        'post_type'     => 'page',
        'page_template'  => 'full-width-page.php'
      );
      if( !is_page('mc-login') ){
        $id = wp_insert_post( $login_page );
        update_option('_mc_class_login_page_id',$id);
        update_post_meta($id,'_wp_page_template','class-makr-full-width-template.php');
      }
    }

    $mc_registration =  get_page_by_title( 'MC Registration' );
    if($mc_registration == NULL || $mc_registration->post_status == 'trash' ){
      $registration_page = array(
        'post_title'    => 'MC Registration',
        'post_content'  => '[MASTERCLASS_REGISTRATION]',
        'post_status'   => 'publish',
        'post_author'   => get_current_user_id(),
        'post_type'     => 'page',
        'page_template'  => 'full-width-page.php'
      );
      if( !is_page('mc-registration') ){
        $id = wp_insert_post( $registration_page );
        update_option('_mc_class_registration_page_id',$id);
        update_post_meta($id,'_wp_page_template','class-makr-full-width-template.php');
      }
    }

    $mc_dashboard =  get_page_by_title( 'MC Dashboard' );
    if($mc_dashboard == NULL || $mc_dashboard->post_status == 'trash' ){
      $account_page = array(
        'post_title'    => 'MC Dashboard',
        'post_content'  => '[MASTERCLASS_DASHBOARD]',
        'post_status'   => 'publish',
        'post_author'   => get_current_user_id(),
        'post_type'     => 'page',
        'page_template'  => 'full-width-page.php'
      );
      if( !is_page('mc-dashboard') ){
        $id = wp_insert_post( $account_page );
        update_option('_mc_class_account_page_id',$id);
        update_post_meta($id,'_wp_page_template','class-makr-full-width-template.php');
      }
    }

    $mc_bundle =  get_page_by_title( 'MC Bundle' );
    if($mc_bundle == NULL || $mc_bundle->post_status == 'trash' ){
      $bundle_page = array(
        'post_title'    => 'MC Bundle',
        'post_content'  => '[MASTERCLASS_BUNDLE]',
        'post_status'   => 'publish',
        'post_author'   => get_current_user_id(),
        'post_type'     => 'page',
        'page_template'  => 'full-width-page.php'
      );
      if( !is_page('mc-bundle') ){
        $id = wp_insert_post( $bundle_page );
        update_option('_mc_class_bundle_page_id',$id);
        update_option('_mc_class_bundle_id',$id);
        update_post_meta($id,'_wp_page_template','class-makr-full-width-template.php');
      }
    }
    global $wp_rewrite;
    $permalink_structure=get_option('permalink_structure');
    $permalink_structure = sanitize_option( 'permalink_structure', $permalink_structure );
    $wp_rewrite->set_permalink_structure( $permalink_structure );
}

function mc_show_ssl_not_found_msg(){
  update_option('mc_cls_square_status','disable');
  update_option('mc_cls_stripe_status','disable')
  ?>
  <div class="notice notice-error">
    <p>SSL certificate is not detected. Class Makr Square and Stripe payment needs SSL on site to work.</p>
  </div>
  <?php
}

require 'vendor/plugin-update-checker/plugin-update-checker.php';
    $myUpdateChecker = PucFactory::buildUpdateChecker(
    'https://plugin-update-control.s3.us-west-1.amazonaws.com/master_class.json',
   __FILE__
);
