<?php
class Navigation_Controller
{
	
	public function get_master_class_navigation( $t_id, $taxonomy = 'category' ) 
	{
	    if ( 'category' === $taxonomy ) {
	        if ( !is_category() )
	            return false;
	    } elseif ( 'post_tag' === $taxonomy ) {
	        if ( !is_tag() )
	            return false;
	    } else {
	        if ( !is_tax( $taxonomy ) )
	            return false;
	    }

	    if (    'category' !== $taxonomy 
	         || 'post_tag' !== $taxonomy
	    ) {
	        $taxonomy = filter_var( $taxonomy, FILTER_SANITIZE_STRING );
	        if ( !$taxonomy )
	            return false;

	        if ( !taxonomy_exists( $taxonomy ) )
	            return false;
	    }

	    
	    $current_term = get_term( $t_id , $taxonomy );


	    // Get all the terms ordered by slug 
	    $terms = get_terms(  array(
		    'taxonomy' => $taxonomy,
		    'hide_empty' => false,
		));


	    // Make sure we have terms before we continue
	    if ( !$terms ) 
	        return false;

	    // Because empty terms stuffs around with array keys, lets reset them
	    $terms = array_values( $terms );

	    // Lets get all the term id's from the array of term objects
	    $term_ids = wp_list_pluck( $terms, 'term_id' );


	    /**
	     * We now need to locate the position of the current term amongs the $term_ids array. \
	     * This way, we can now know which terms are adjacent to the current one
	     */
	    $current_term_position = array_search( $current_term->term_id, $term_ids );

	    // Set default variables to hold the next and previous terms
	    $previous_term = '';
	    $next_term     = '';

	    // Get the previous term
	    if ( 0 !== $current_term_position ) 
	        $previous_term = $terms[$current_term_position - 1];

	    // Get the next term
	    if ( intval( count( $term_ids ) - 1 ) !== $current_term_position ) 
	        $next_term = $terms[$current_term_position + 1];

	    $link = [];
	    // Build the links
	    if ( $previous_term ) 
	        $link[] = '<span class="dashicons dashicons-arrow-left"></span> Previous Class: <a href="' . esc_url( get_term_link( $previous_term ) ) . '">' . $previous_term->name . '</a>';

	    if ( $next_term ) 
	        $link[] = 'Next Class: <a href="' . esc_url( get_term_link( $next_term ) ) . '">' . $next_term->name . '</a> <span class="dashicons dashicons-arrow-right"></span>';

	    return implode( ' | ', $link );
	}

	public static function previous_lesson_link_output(){
		ob_start();
		$prev_post = get_adjacent_post( true, '', false, 'mc-class-category' );
		
		if (!empty( $prev_post )): ?>
			<div id="mcNavigation" class="mc_pagination">
  				<span class="dashicons dashicons-arrow-left"></span> Previous Class: <a href="<?php echo esc_url( get_permalink( $prev_post->ID ) ); ?>"><?php echo esc_attr( $prev_post->post_title ); ?></a>
  			</div>
  		<?php
  		endif;
  		return ob_get_clean();
		
	}

	public static function next_lesson_link_output(){
		ob_start();
  		$next_post = get_adjacent_post( true, '', true, 'mc-class-category' );
		
		if (!empty( $next_post )): ?>
			<div id="mcNavigation" class="mc_pagination">
  				Next Class: <a href="<?php echo esc_url( get_permalink( $next_post->ID ) ); ?>"><?php echo esc_attr( $next_post->post_title ); ?></a><span class="dashicons dashicons-arrow-right"></span>
  			</div>
  		<?php
  		endif;
  		return ob_get_clean();
	}
	public static function get_next_post_id( $post_id ) {
	    // Get a global post reference since get_adjacent_post() references it
	    global $post;
	    // Store the existing post object for later so we don't lose it
	    $oldGlobal = $post;
	    // Get the post object for the specified post and place it in the global variable
	    $post = get_post( $post_id );
	    // Get the post object for the previous post
	    $previous_post = get_previous_post();
	    // Reset our global object
	    $post = $oldGlobal;
	    if ( '' == $previous_post ) 
	        return 0;
	    return $previous_post->ID; 
	} 

	public static function get_previous_post_id( $post_id ) {
	    // Get a global post reference since get_adjacent_post() references it
	    global $post;
	    // Store the existing post object for later so we don't lose it
	    $oldGlobal = $post;
	    // Get the post object for the specified post and place it in the global variable
	    $post = get_post( $post_id );
	    // Get the post object for the next post
	    $next_post = get_next_post();
	    // Reset our global object
	    $post = $oldGlobal;
	    if ( '' == $next_post ) 
	        return 0;
	    return $next_post->ID; 
	} 
}